==> qtermwidget_1.4.0.orig.tar.xz: qtermwidget-1.4.0/lib/translations/qtermwidget_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>Konsole::Session</name>
    <message>
        <location filename="../Session.cpp" line="454"/>
        <source>Bell in session &apos;%1&apos;</source>
        <translation>Zvonček v relácií &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="606"/>
        <source>Session &apos;%1&apos; exited with code %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="608"/>
        <source>Session &apos;%1&apos; crashed.</source>
        <translation>Relácia &apos;%1&apos; spadla.</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="613"/>
        <source>Session &apos;%1&apos; exited unexpectedly.</source>
        <translation>Relácia &apos;%1&apos; bola neočakávane ukončená.</translation>
    </message>
</context>
<context>
    <name>Konsole::TerminalDisplay</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1275"/>
        <source>Size: XXX x XXX</source>
        <translation>Veľkosť: XXX x XXX</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1287"/>
        <source>Size: %1 x %2</source>
        <translation>Veľkosť: %1 x %2</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2787"/>
        <source>Paste multiline text</source>
        <translation>Prilepiť viacriadkový text</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2788"/>
        <source>Are you sure you want to paste this text?</source>
        <translation>Prajete si prilepiť tento text?</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="3258"/>
        <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Výstup bol &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;pozastavený&lt;/a&gt; stlačením Ctrl+S.  Stlačte&lt;b&gt;Ctrl+Q&lt;/b&gt; pre opätovné spustenie.&lt;/qt&gt;</translation>
    </message>
</context>
<context>
    <name>Konsole::Vt102Emulation</name>
    <message>
        <location filename="../Vt102Emulation.cpp" line="1121"/>
        <source>No keyboard translator available.  The information needed to convert key presses into characters to send to the terminal is missing.</source>
        <translation>Prekladač klávesnice nie je dostupný. Chýbajú preto informácie potrebné na prevod kódov stlačených kláves na znaky poslané na terminál.</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2794"/>
        <source>Show Details...</source>
        <translation>Zobraziť podrobnosti...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../ColorScheme.cpp" line="275"/>
        <location filename="../ColorScheme.cpp" line="290"/>
        <source>Un-named Color Scheme</source>
        <translation>Farebná schéma bez mena</translation>
    </message>
    <message>
        <location filename="../ColorScheme.cpp" line="461"/>
        <source>Accessible Color Scheme</source>
        <translation>Farebná schéma pre zjednodušený prístup</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="515"/>
        <source>Open Link</source>
        <translation>Otvoriť odkaz</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="516"/>
        <source>Copy Link Address</source>
        <translation>Kopírovať adresu odkazu</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="520"/>
        <source>Send Email To...</source>
        <translation>Poslať email na adresu...</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="521"/>
        <source>Copy Email Address</source>
        <translation>Kopírovať e-mailovú adresu</translation>
    </message>
</context>
<context>
    <name>QTermWidget</name>
    <message>
        <location filename="../qtermwidget.cpp" line="469"/>
        <source>Color Scheme Error</source>
        <translation>Chyba vo farebnej schéme</translation>
    </message>
    <message>
        <location filename="../qtermwidget.cpp" line="470"/>
        <source>Cannot load color scheme: %1</source>
        <translation>Nepodarilo sa načítať schému: %1</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../SearchBar.cpp" line="40"/>
        <source>Match case</source>
        <translation>Rozlišovať veľké a malé písmená</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="46"/>
        <source>Regular expression</source>
        <translation>Regulárny výraz</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="50"/>
        <source>Highlight all matches</source>
        <translation>Zvýrazniť všetky zhody</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="14"/>
        <source>SearchBar</source>
        <translation>Hľadanie</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="20"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="32"/>
        <source>Find:</source>
        <translation>Hľadať:</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="42"/>
        <source>&lt;</source>
        <translation>&lt;</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="54"/>
        <source>&gt;</source>
        <translation>&gt;</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="66"/>
        <source>...</source>
        <translation>...</translation>
    </message>
</context>
</TS>

==> qtermwidget_2.1.0.orig.tar.xz: qtermwidget-2.1.0/lib/translations/qtermwidget_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>Konsole::Session</name>
    <message>
        <location filename="../Session.cpp" line="448"/>
        <source>Bell in session &apos;%1&apos;</source>
        <translation>Zvonček v relácií &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="600"/>
        <source>Session &apos;%1&apos; exited with code %2.</source>
        <translation>Relácia &apos;%1&apos; bola ukončená s kódom %2.</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="602"/>
        <source>Session &apos;%1&apos; crashed.</source>
        <translation>Relácia &apos;%1&apos; spadla.</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="607"/>
        <source>Session &apos;%1&apos; exited unexpectedly.</source>
        <translation>Relácia &apos;%1&apos; bola neočakávane ukončená.</translation>
    </message>
</context>
<context>
    <name>Konsole::TerminalDisplay</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1278"/>
        <source>Size: XXX x XXX</source>
        <translation>Veľkosť: XXX x XXX</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1290"/>
        <source>Size: %1 x %2</source>
        <translation>Veľkosť: %1 x %2</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2790"/>
        <source>Paste multiline text</source>
        <translation>Prilepiť viacriadkový text</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2791"/>
        <source>Are you sure you want to paste this text?</source>
        <translation>Prajete si prilepiť tento text?</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="3261"/>
        <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Výstup bol &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;pozastavený&lt;/a&gt; stlačením Ctrl+S.  Stlačte&lt;b&gt;Ctrl+Q&lt;/b&gt; pre opätovné spustenie.&lt;/qt&gt;</translation>
    </message>
</context>
<context>
    <name>Konsole::Vt102Emulation</name>
    <message>
        <location filename="../Vt102Emulation.cpp" line="1106"/>
        <source>No keyboard translator available.  The information needed to convert key presses into characters to send to the terminal is missing.</source>
        <translation>Prekladač klávesnice nie je dostupný. Chýbajú preto informácie potrebné na prevod kódov stlačených kláves na znaky poslané na terminál.</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2797"/>
        <source>Show Details...</source>
        <translation>Zobraziť podrobnosti...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../ColorScheme.cpp" line="275"/>
        <location filename="../ColorScheme.cpp" line="290"/>
        <source>Un-named Color Scheme</source>
        <translation>Farebná schéma bez mena</translation>
    </message>
    <message>
        <location filename="../ColorScheme.cpp" line="461"/>
        <source>Accessible Color Scheme</source>
        <translation>Farebná schéma pre zjednodušený prístup</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="520"/>
        <source>Open Link</source>
        <translation>Otvoriť odkaz</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="521"/>
        <source>Copy Link Address</source>
        <translation>Kopírovať adresu odkazu</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="525"/>
        <source>Send Email To...</source>
        <translation>Poslať email na adresu...</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="526"/>
        <source>Copy Email Address</source>
        <translation>Kopírovať e-mailovú adresu</translation>
    </message>
</context>
<context>
    <name>QTermWidget</name>
    <message>
        <location filename="../qtermwidget.cpp" line="465"/>
        <source>Color Scheme Error</source>
        <translation>Chyba vo farebnej schéme</translation>
    </message>
    <message>
        <location filename="../qtermwidget.cpp" line="466"/>
        <source>Cannot load color scheme: %1</source>
        <translation>Nepodarilo sa načítať schému: %1</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../SearchBar.cpp" line="39"/>
        <source>Match case</source>
        <translation>Rozlišovať veľké a malé písmená</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="45"/>
        <source>Regular expression</source>
        <translation>Regulárny výraz</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="49"/>
        <source>Highlight all matches</source>
        <translation>Zvýrazniť všetky zhody</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="14"/>
        <source>SearchBar</source>
        <translation>Hľadanie</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="20"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="32"/>
        <source>Find:</source>
        <translation>Hľadať:</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="42"/>
        <source>&lt;</source>
        <translation>&lt;</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="54"/>
        <source>&gt;</source>
        <translation>&gt;</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="66"/>
        <source>...</source>
        <translation>...</translation>
    </message>
</context>
</TS>
